summaryrefslogtreecommitdiff
path: root/lib/libc/arch/alpha
diff options
context:
space:
mode:
authorTheo de Raadt <deraadt@cvs.openbsd.org>2004-01-15 13:40:23 +0000
committerTheo de Raadt <deraadt@cvs.openbsd.org>2004-01-15 13:40:23 +0000
commit09d5fbfc6f24fd2f95eb7cf67f75c6a61c9246e0 (patch)
treec2ea7a9f71b4ff4d81126b52b1e3e3889028fde1 /lib/libc/arch/alpha
parent1eab234346d0a48e8df1dc8ce7bbdc4f8a3bdf78 (diff)
ABI breakage happened with the sigaltstack replacement. It is too late,
now we just have to cope. Since setjmp uses it, the alpha and sparc64 are unhappy with the structure change. In a few days, we will make the second hop here, for now, use the old system call until all binaries have the new struct in them.
Diffstat (limited to 'lib/libc/arch/alpha')
-rw-r--r--lib/libc/arch/alpha/gen/setjmp.S8
1 files changed, 4 insertions, 4 deletions
diff --git a/lib/libc/arch/alpha/gen/setjmp.S b/lib/libc/arch/alpha/gen/setjmp.S
index 66d0d42b4e7..30909064fbf 100644
--- a/lib/libc/arch/alpha/gen/setjmp.S
+++ b/lib/libc/arch/alpha/gen/setjmp.S
@@ -1,4 +1,4 @@
-/* $OpenBSD: setjmp.S,v 1.4 2002/01/04 13:51:20 art Exp $ */
+/* $OpenBSD: setjmp.S,v 1.5 2004/01/15 13:39:38 deraadt Exp $ */
/* $NetBSD: setjmp.S,v 1.2 1996/10/17 03:08:06 cgd Exp $ */
/*
@@ -32,7 +32,7 @@
#if defined(LIBC_SCCS)
.text
- .asciz "$OpenBSD: setjmp.S,v 1.4 2002/01/04 13:51:20 art Exp $"
+ .asciz "$OpenBSD: setjmp.S,v 1.5 2004/01/15 13:39:38 deraadt Exp $"
#endif
/*
@@ -71,10 +71,10 @@ LEAF(setjmp, 1)
CALL(sigblock) /* see what's blocked */
stq v0, (1 * 8)(s0) /* and remember it in sc_mask */
- lda sp, -16(sp) /* sizeof struct sigaltstack */
+ lda sp, -16(sp) /* sizeof struct osigaltstack */
mov zero, a0
mov sp, a1
- CALL(sigaltstack)
+ CALL(osigaltstack)
ldl t0, 12(sp)
lda sp, 16(sp)
ldq ra, ((26 + 4) * 8)(s0) /* restore return address */